jam-bootstrap-service-0.1.21 is not a library.
Visit the last successful build:
jam-bootstrap-service-0.1.28
The JAM Bootstrap Service
This simple service can be placed in Genesis and Work Items filled with Instructions as per the jam-bootstrap-service-common can be fed into it to elicit particular actions on-chain and in-core.